@@ -1,11 +1,11 @@
-function [f,s] = format (arg)
+function [f,s,iso] = format (arg)
 %GRB.FORMAT get/set the default GraphBLAS matrix format.
 %
 % In its ANSI C interface, SuiteSparse:GraphBLAS stores its matrices by
 % row, by default, since that format tends to be fastest for graph
-% algorithms, but it can also store its matrices by column.  MATLAB sparse
-% and full matrices are always stored by column.  For better compatibility
-% with MATLAB matrices, the default for the MATLAB interface for
+% algorithms, but it can also store its matrices by column.  Built-in
+% sparse and full matrices are always stored by column.  For better
+% compatibility with built-in matrices, the default for this interface for
 % SuiteSparse:GraphBLAS is to store matrices by column.  This has
 % performance implications, and algorithms should be designed accordingly.
 % The default format can be can changed via:
@@ -23,7 +23,7 @@ function [f,s] = format (arg)
 % which returns the string 'by row' or 'by col'.
 %
 % Converting a matrix to a specific format can be done with the following,
-% where A is either a GraphBLAS matrix or MATLAB matrix:
+% where A is either a GraphBLAS matrix or built-in matrix:
 %
 %   G = GrB (A, 'by row')
 %
@@ -63,10 +63,10 @@ function [f,s] = format (arg)
 %
 % To query the format for a given GraphBLAS matrix G, use the following
 % (which does not affect the global format setting).  The return value f
-% is 'by row' or 'by col', and s is 'hypersparse', 'sparse', 'bitmap',
-% or 'full'.
+% is 'by row' or 'by col', s is 'hypersparse', 'sparse', 'bitmap',
+% or 'full', and iso is 'iso-valued' or 'non-iso-valued'.
 %
-%   [f,s] = GrB.format (G)
+%   [f,s,iso] = GrB.format (G)
 %
 % Use G = GrB (G, 'by row') or G = GrB (G, 'by col') to change the format
 % of G after it is constructed.
@@ -79,15 +79,15 @@ function [f,s] = format (arg)
 %   (1) 'hypersparse' (or 'hyper' for short):  This is useful if A
 %       n << e and A is 'by col', or m << e if A is 'by row'.  The data
 %       structure takes only O (e) space.
-%   (2) 'sparse':  This the same as the MATLAB sparse matrix, except that
+%   (2) 'sparse':  This the same as the built-in sparse matrix, except that
 %       A can be either 'by col' (taking O(n+e) space), or 'by row'
-%       taking O(m+e) space.  A native MATLAB sparse matrix is only held
+%       taking O(m+e) space.  A native built-in sparse matrix is only held
 %       'by col'.
 %   (3) 'bitmap':  This data structure takes O(m*n) space, but it can
 %       represent a sparse matrix with e < m*n.  It is very efficient
 %       if e is about 0.1*m*n or greater.
 %   (4) 'full':  This takes O(m*n) sparse, and 'full by col' is the same
-%       as a MATLAB full matrix.  All entries must be present (e == m*n).
+%       as a built-in full matrix.  All entries must be present (e == m*n).
 %       GraphBLAS can also store a matrix 'full by row'.
 %
 % The sparsity formats can be combined.  For example, to store a matrix in
@@ -110,23 +110,32 @@ function [f,s] = format (arg)
 %   GrB.format (G)
 %   GrB.format ('by row') ;      % set the default format to 'by row'
 %   G = GrB.build (1:3, 1:3, 1:3)
-%   [f,s] = GrB.format (G)       % query the format of G
+%   [f,s,iso] = GrB.format (G)   % query the format of G
+%   C = GrB.ones (2^60)          % now that's a big matrix
+%   [f,s,iso] = GrB.format (C)
 %
 % See also GrB.
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2021, All Rights Reserved.
-% SPDX-License-Identifier: GPL-3.0-or-later
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2023, All Rights Reserved.
+% SPDX-License-Identifier: Apache-2.0
 
 if (nargin == 0)
     % f = GrB.format ; get the global format
+    if (nargout > 1)
+        error ('GrB:error', 'usage: f = GrB.format') ;
+    end
     f = gbformat ;
 else
     if (isobject (arg))
         % f = GrB.format (G) ; get the format of the GraphBLAS matrix
         arg = arg.opaque ;
     end
-    % f = GrB.format (A) ; get the format of the matrix A (MATLAB or GraphBLAS)
+    % f = GrB.format (A) ; get the format of A (built-in or GraphBLAS)
     % f = GrB.format (f) ; set the global format for all matrices.
-    [f,s] = gbformat (arg) ;
+    if (nargout <= 1)
+        f = gbformat (arg) ;
+    else
+        [f,s,iso] = gbformat (arg) ;
+    end
 end
 
