@@ -2,8 +2,8 @@ function C = gb_max3 (op, A, option)
 %GB_MAX3 3-input max
 % Implements C = max (A, [ ], option)
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2021, All Rights Reserved.
-% SPDX-License-Identifier: GPL-3.0-or-later
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2023, All Rights Reserved.
+% SPDX-License-Identifier: Apache-2.0
 
 if (isequal (option, 'all'))
     % C = max (A, [ ] 'all'), reducing all entries to a scalar
@@ -19,7 +19,7 @@ else
         % giving an m-by-1 column vector.
         C = gb_maxbyrow (op, A) ;
     else
-        error ('invalid option') ;
+        error ('GrB:error', 'invalid option') ;
     end
 end
 
