@@ -2,8 +2,8 @@
 // gb_mxarray_to_descriptor: get the contents of a GraphBLAS Descriptor
 //------------------------------------------------------------------------------
 
-// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2023, All Rights Reserved.
+// SPDX-License-Identifier: Apache-2.0
 
 //------------------------------------------------------------------------------
 
@@ -32,23 +32,11 @@ static void get_descriptor
 
         if (MATCH (fieldname, "nthreads"))
         { 
-
-            // nthreads must be a numeric scalar
-            CHECK_ERROR (!gb_mxarray_is_scalar (value),
-                "d.nthreads must be a scalar") ;
-            int nthreads_max = (int) mxGetScalar (value) ;
-            OK (GxB_Desc_set (desc, GxB_NTHREADS, nthreads_max)) ;
-
+            // ignored
         }
         else if (MATCH (fieldname, "chunk"))
         { 
-
-            // chunk must be a numeric scalar
-            CHECK_ERROR (!gb_mxarray_is_scalar (value),
-                "d.chunk must be a scalar") ;
-            double chunk = mxGetScalar (value) ;
-            OK (GxB_Desc_set (desc, GxB_CHUNK, chunk)) ;
-
+            // ignored
         }
         else
         {
@@ -132,6 +120,7 @@ GrB_Descriptor gb_mxarray_to_descriptor // new descriptor, or NULL if none
     (*sparsity) = 0 ;
 
     if (desc_builtin == NULL || !mxIsStruct (desc_builtin)
+        || (mxGetField (desc_builtin, 0, "GraphBLASv7_3") != NULL)
         || (mxGetField (desc_builtin, 0, "GraphBLASv5_1") != NULL)
         || (mxGetField (desc_builtin, 0, "GraphBLASv5") != NULL)
         || (mxGetField (desc_builtin, 0, "GraphBLASv4") != NULL)
@@ -156,8 +145,6 @@ GrB_Descriptor gb_mxarray_to_descriptor // new descriptor, or NULL if none
     get_descriptor (desc, desc_builtin, "in1"     , GrB_INP1) ;
     get_descriptor (desc, desc_builtin, "mask"    , GrB_MASK) ;
     get_descriptor (desc, desc_builtin, "axb"     , GxB_AxB_METHOD) ;
-    get_descriptor (desc, desc_builtin, "nthreads", GxB_NTHREADS) ;
-    get_descriptor (desc, desc_builtin, "chunk"   , GxB_CHUNK) ;
 
     //--------------------------------------------------------------------------
     // get the desired kind of output
