@@ -1,9 +1,10 @@
 function gbtest95
 %GBTEST95 test indexing
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2021, All Rights Reserved.
-% SPDX-License-Identifier: GPL-3.0-or-later
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2023, All Rights Reserved.
+% SPDX-License-Identifier: Apache-2.0
 
+have_octave = gb_octave ;
 G = GrB.empty (GrB ([0 2])) ;
 assert (isequal (size (G), [0 2])) ;
 
@@ -43,10 +44,14 @@ assert (istril (C)) ;
 types = gbtest_types ;
 for k = 1:length (types)
     type = types {k} ;
-    if (contains (type, 'complex') || isequal (type, 'logical'))
+    if (gb_contains (type, 'complex') || isequal (type, 'logical'))
         continue ;
     end
     I = GrB ([1 2], type) ;
+    if (have_octave)
+        % octave: indices into built-in matrices cannot be objects
+        I = int64 (I) ;
+    end
     C1 = A (I,I) ;
     C2 = A ([1 2], [1 2]) ;
     C3 = A (int8 ([1 2]), int8 ([1 2])) ;
@@ -56,15 +61,18 @@ for k = 1:length (types)
     assert (isequal (C1, C4))
 end
 
-I1 = [1 2 ; 3 4] ;
-I2 = GrB (I1) ;
-C1 = A (I1,I1) ;
-C2 = A (I2,I2) ;
-H = GrB (2^60, 2^60) ;
-H (1:2,1:2) = I1 ;
-C3 = A (H,H) ;
-assert (isequal (C1, C2))
-assert (isequal (C1, C3))
+if (~have_octave)
+    % octave: indices into built-in matrices cannot be objects
+    I1 = [1 2 ; 3 4] ;
+    I2 = GrB (I1) ;
+    C1 = A (I1,I1) ;
+    C2 = A (I2,I2) ;
+    H = GrB (2^60, 2^60) ;
+    H (1:2,1:2) = I1 ;
+    C3 = A (H,H) ;
+    assert (isequal (C1, C2))
+    assert (isequal (C1, C3))
+end
 
 A = [-1 2] ;
 B = [2 0.5] ;
