@@ -19,27 +19,32 @@ copyfile ('../GraphBLAS/rename/GB_rename.h', 'tmp_include/GB_rename.h') ;
 copyfile ('GB_coverage.c', 'tmp_source/GB_coverage.c') ;
 
 % create the include files and place in tmp_include
-hfiles = [ dir('../Include/*') ; ...
-           dir('../Source/*.h') ; ...
-           dir('../GraphBLAS/Config/*.h') ; ...
-           dir('../Source/Template') ; ...
-           dir('../Source/Factories') ; ...
-           dir('../Source/Shared') ; ...
-           dir('../JITpackage/*.h') ; ...
-           dir('../Source/FactoryKernels/*.h') ; ] ;
+hfiles = [ ...
+        dir('../Include/GraphBLAS.h') ; ...
+        dir('../Source/*.h') ; ...
+        dir('../GraphBLAS/Config/*.h') ; ...
+        dir('../Source/include') ; ...
+        dir('../Source/*/*.h') ; ...
+        dir('../Source/*/include') ; ...
+        dir('../Source/*/template') ; ...
+        dir('../Source/*/factory') ; ...
+        dir('../JITpackage/*.h') ; ...
+        dir('../FactoryKernels/*.h') ; ] ;
+
 count = grbcover_edit (hfiles, 0, 'tmp_include') ;
 fprintf ('hfile count: %d\n', count) ;
 
 % create the C files and place in tmp_source
-cfiles = [ dir('../Source/*.c') ; ...
-           dir('../Source/FactoryKernels/*.c') ; ...
-           % use Tcov/PreJIT kernels ...
-           dir('PreJIT/*.c') ; ...
-           % not the PreJIT kernels in the primary source
-           % dir('../PreJIT/*.c') ; ...
-           % dir('../Config/GB_prejit.c') ; ...
-           dir('../JITpackage/*.c')
-           ] ;
+cfiles = [ dir('../Source/*/*.c') ; ...
+        dir('../FactoryKernels/*.c') ; ...
+        % use Tcov/PreJIT kernels ...
+        dir('PreJIT/*.c') ; ...
+        % not the PreJIT kernels in the primary source:
+        % dir('../PreJIT/*.c') ; ...
+        % dir('../Config/GB_prejit.c') ; ...
+        dir('../JITpackage/*.c')
+        ] ;
+
 count = grbcover_edit (cfiles, count, 'tmp_source') ;
 fprintf ('cfile count: %d\n', count) ;
 
@@ -48,7 +53,7 @@ fp = fopen ('tmp_cover/count', 'w') ;
 fprintf (fp, '%d\n', count) ;
 fclose (fp) ;
 
-% revise this to match Source/Template/GB_coverage.h
+% revise this to match Source/include/GB_coverage.h
 GBCOVER_MAX = 31000 ;
 assert (count < GBCOVER_MAX) ;
 
