@@ -1,14 +1,14 @@
 //------------------------------------------------------------------------------
-// GB_mex_cast: cast a MATLAB array using C-style casting rules
+// GB_mex_cast: cast a built-in array using C-style casting rules
 //------------------------------------------------------------------------------
 
-// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2021, All Rights Reserved.
+// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2023, All Rights Reserved.
 // SPDX-License-Identifier: Apache-2.0
 
 //------------------------------------------------------------------------------
 
 // Usage: C = GB_mex_cast (X, type) casts the dense array X to given type using
-// C-style typecasting rules instead of MATLAB's rules.
+// C-style typecasting rules instead of built-in rules.
 
 #include "GB_mex.h"
 
@@ -23,6 +23,9 @@ void mexFunction
 )
 {
 
+    struct GB_Matrix_opaque T_header ;
+    GrB_Matrix T = NULL ;
+
     // do not get coverage counts unless the 3rd arg is present
     bool do_cover = (nargin == 3) ;
     bool malloc_debug = GB_mx_get_global (do_cover) ;
@@ -62,8 +65,24 @@ void mexFunction
     GB_void *C = mxGetData (pargout [0]) ;
 
     // cast the data from X to C
-    GB_cast_array (C, ctype->code, X, xtype->code, NULL,
-        xtype->size, nrows*ncols, 1) ;
+    int64_t cnz = nrows*ncols ;
+    if (C == NULL && cnz > 0) mexErrMsgTxt ("C is NULL!\n") ;
+    if (ctype == xtype)
+    {
+        memcpy (C, X, cnz * xtype->size) ;
+    }
+    else
+    {
+        // create a shallow cnz-by-1 matrix T to wrap the array X
+        T = NULL ;
+        void *Tx = X ;
+        GrB_Index nrows = cnz, ncols = 1, Tx_size = cnz * xtype->size ;
+        GxB_Matrix_import_FullC (&T, xtype, nrows, ncols, &Tx, Tx_size, false, NULL) ;
+        // GB_cast_array (C, ctype->code, X, xtype->code, NULL, cnz, 1) ;
+        GB_cast_array (C, ctype->code, T, 1) ;
+        bool iso ;
+        GxB_Matrix_export_FullC (&T, &xtype, &nrows, &ncols, &Tx, &Tx_size, &iso, NULL) ;
+    }
 
     GB_mx_put_global (do_cover) ;
 }
