@@ -9,8 +9,8 @@
 
 #include "GB_mex.h"
 #include "GB_mex_errors.h"
-#include "GB_file.h"
-#include "GB_jitifyer.h"
+#include "../Source/jitifyer/GB_file.h"
+#include "../Source/jitifyer/GB_jitifyer.h"
 
 #define USAGE "GB_mex_test11"
 
@@ -235,6 +235,17 @@ if (jit_enabled)
     OK (GxB_Global_Option_get_CHAR (GxB_JIT_C_PREFACE, &t)) ;
     CHECK (MATCH (t, "// more stuff here")) ;
 
+    OK (GxB_get (GxB_JIT_CUDA_PREFACE, &s)) ;
+    printf ("default CUDA preface [%s]\n", s) ;
+    OK (GxB_set (GxB_JIT_CUDA_PREFACE, "// cuda stuff here")) ;
+    OK (GxB_get (GxB_JIT_CUDA_PREFACE, &s)) ;
+    CHECK (MATCH (s, "// cuda stuff here")) ;
+    OK (GxB_Global_Option_get_CHAR (GxB_JIT_CUDA_PREFACE, &t)) ;
+    CHECK (MATCH (t, "// cuda stuff here")) ;
+    OK (GxB_Global_Option_set_CHAR (GxB_JIT_CUDA_PREFACE,
+        "// more cuda stuff here")) ;
+    OK (GxB_Global_Option_get_CHAR (GxB_JIT_CUDA_PREFACE, &t)) ;
+    CHECK (MATCH (t, "// more cuda stuff here")) ;
 
     OK (GxB_Type_new (&MyType, 0, "mytype", "typedef double mytype ;")) ;
     OK (GxB_Type_size (&mysize, MyType)) ;
@@ -297,7 +308,11 @@ if (jit_enabled)
     OK (GxB_get (GxB_JIT_CACHE_PATH, &s)) ;
     printf ("new cache path: [%s]\n", s) ;
     CHECK (MATCH (s, "/tmp/grb_cache")) ;
-    printf ("\nat %d cache path: [%s]\n", __LINE__, save_cache) ;
+
+    OK (GxB_set (GxB_JIT_CACHE_PATH, "/tmp/::tmp/grb_@cache \\gunk??")) ;
+    OK (GxB_get (GxB_JIT_CACHE_PATH, &s)) ;
+    printf ("\nfixed cache path: [%s]\n", s) ;
+    CHECK (MATCH (s, "/tmp/__tmp/grb__cache /gunk__")) ;
 
     expected = GrB_INVALID_VALUE ;
     ERR (GxB_Global_Option_set_CHAR (999, "gunk")) ;
