@@ -1,5 +1,5 @@
 function Cout = GB_spec_matrix (Cin, identity)
-%GB_SPEC_MATRIX a MATLAB mimic that conforms a matrix to the GraphBLAS spec
+%GB_SPEC_MATRIX a mimic that conforms a matrix to the GraphBLAS spec
 %
 % Cout = GB_spec_matrix (Cin)
 % Cout = GB_spec_matrix (Cin, identity)
@@ -19,12 +19,12 @@ function Cout = GB_spec_matrix (Cin, identity)
 % of X is given by Cin.pattern; otherwise the pattern for a sparse X is
 % GB_spones_mex(X) and entries outside the pattern are assumed to be equal to
 % identity.  For a dense X, with no Cin.pattern present the pattern of X is
-% just X ~= identity.
+% all true.
 %
-% Cin is a matrix, then its type is given by GB_spec_type (Cin).  If the
+% If Cin is a matrix, then its type is given by GB_spec_type (Cin).  If the
 % matrix is sparse, its pattern is GB_spones_mex(Cin) and entries not in the
-% pattern are assumed equal to identity.  Otherwise the pattern of Cin is given
-% by Cin ~= identity.
+% pattern are assumed equal to identity.  Otherwise the pattern of Cin is
+% all true.
 %
 % The output Cout is a struct with all three fields present (matrix, pattern,
 % and type).  Cout.matrix is dense, and it has been typecast into the type
@@ -32,9 +32,7 @@ function Cout = GB_spec_matrix (Cin, identity)
 % identity.
 %
 % The matrix is typecast to Cout.class using the typecasting GraphBLAS
-% typecasting rules, which differ from MATLAB's rules, particular for integer
-% types.  Since MATLAB can only represent 'logical' and 'double' sparse
-% matries, the matrix is converted to full.
+% typecasting rules.
 %
 % Converting a matrix from sparse to full is not part of the GraphBLAS spec, of
 % course.  Neither is the identity value a part of the matrix structure in
@@ -46,13 +44,13 @@ function Cout = GB_spec_matrix (Cin, identity)
 % the implicit zero, with a change to the GraphBLAS data structure for the
 % matrix.
 %
-% However, MATLAB only supports logical, double, and double complex
-% sparse matrices, so to the MATLAB mimic functions GB_spec_* operate only on
-% dense matrices.  When a MATLAB sparse matrix is converted into a dense matrix,
+% However, built-in methods only support logical, double, and double complex
+% sparse matrices, so to the mimic functions GB_spec_* operate only on dense
+% matrices.  When a built-in sparse matrix is converted into a dense matrix,
 % the entries not in the pattern must be set to an explicit value: the
 % addititive identity.
 %
-% The MATLAB mimic routines, GB_spec_* are written almost purely in M, and
+% The mimic routines, GB_spec_* are written almost purely in M, and
 % do not call GraphBLAS functions (with the exception of typecasting and
 % operators).  They always return a stuct C with a dense C.matrix, a
 % pattern C.pattern and type C.class.
@@ -65,8 +63,8 @@ function Cout = GB_spec_matrix (Cin, identity)
 % must first be passed to this function, C0=GB_spec_matrix(C0,identity) and
 % then C0 and C1 should be identical.
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
-% http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2023, All Rights Reserved.
+% SPDX-License-Identifier: Apache-2.0
 
 % get the semiring addititive identity, if present
 if (nargin < 2)
@@ -108,7 +106,8 @@ else
         % the pattern are assumed to be equal to the addititve identity.
         xpattern = GB_mex_cast (full (GB_spones_mex (X)), 'logical') ;
     else
-        xpattern = (X ~= identity) ;
+        xpattern = true (size (X)) ;
+        % xpattern = (X ~= identity) ;
     end
 end
 
@@ -120,7 +119,7 @@ if (isstruct (Cin) && isfield (Cin, 'values') &&  ...
     % to int64 or uint64 can lead to loss of precision.  So in this case,
     % use Cin.values instead.
     X = GB_spec_zeros (size (Cin.matrix), xtype) ;
-    [I J ~] = find (xpattern) ;
+    [I, J, ~] = find (xpattern) ;
     Cx = Cin.values ;
     assert (length (I) == length (Cx)) ;
     for k = 1:length (Cin.values)
@@ -132,7 +131,8 @@ else
 end
 
 % in the dense X, entries not in the xpattern must be set to the identity
-X (~xpattern) = GB_mex_cast (identity, xtype) ;
+id = GB_mex_cast (identity, xtype) ;
+X (~xpattern) = id ;
 
 if (~isequal (xtype, GB_spec_type (X)))
     % if X is complex, it may have been downgraded to real, if
@@ -150,3 +150,19 @@ Cout.class = xtype ;
 assert (isstruct (Cout)) ;
 assert (~issparse (Cout.matrix)) ;
 
+% handle the iso case
+if (isstruct (Cin) && isfield (Cin, 'iso'))
+    iso = Cin.iso ;
+    if (iso)
+        % get the first entry in the pattern
+        [I,J] = ind2sub (size (xpattern), find (xpattern)) ;
+        if (isempty (I))
+            xiso = 0 ;
+        else
+            xiso = X (I (1), J (1)) ;
+        end
+        Cout.matrix (xpattern) = xiso ;
+    end
+    Cout.iso = iso ;
+end
+
