@@ -1,7 +1,7 @@
 function test191
 %TEST191 test split
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2021, All Rights Reserved.
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2023, All Rights Reserved.
 % SPDX-License-Identifier: Apache-2.0
 
 fprintf ('test191 ----------- Tiles = split (A)\n') ;
@@ -33,6 +33,20 @@ for d = [1e-4 0.01 0.2 0.8 inf]
                         GB_spec_compare (C1 {i,j}, C2 {i,j}) ;
                     end
                 end
+
+                if (nnz (A.matrix) > 0)
+                    % also try the iso case
+                    B = A ;
+                    B.matrix = spones (A.matrix) * pi ;
+                    B.iso = true ;
+                    C2 = GB_spec_split (B, ms, ns) ;
+                    C1 = GB_mex_split  (B, ms, ns) ;
+                    for i = 1:length(ms)
+                        for j = 1:length(ns)
+                            GB_spec_compare (C1 {i,j}, C2 {i,j}) ;
+                        end
+                    end
+                end
             end
         end
     end
