@@ -1,7 +1,7 @@
 function test201
 %TEST201 test iso reduce to vector and reduce to scalar
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2023, All Rights Reserved.
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2024, All Rights Reserved.
 % SPDX-License-Identifier: Apache-2.0
 
 n = 10 ;
@@ -21,4 +21,16 @@ assert (abs (c1-c2) < 1e-12) ;
 c3 = sum (sum (A.matrix)) ;
 assert (abs (c2-c3) < 1e-12) ;
 
+% reduce a huge iso full matrix to a scalar
+m = 2^40 ;
+n = 2^48 ;
+% s = sum (pi * GrB.ones (m, n), 'all')
+s = GB_mex_test36 ;
+% expected result:
+t = pi * m * n ;
+relerr = abs (s - t) / t ;
+relerr
+assert (relerr < 1e-14) ;
+bits = ceil (log2 (t))
+
 fprintf ('test201: all tests passed\n') ;
