@@ -2,6 +2,11 @@
 // === SuiteSparseQR_qmult =====================================================
 // =============================================================================
 
+// SPQR, Copyright (c) 2008-2022, Timothy A Davis. All Rights Reserved.
+// SPDX-License-Identifier: GPL-2.0+
+
+//------------------------------------------------------------------------------
+
 // Applies Q in Householder form to a sparse or dense matrix X.  These functions
 // use the Householder form in plain sparse column form, as returned by
 // the SuiteSparseQR function.
@@ -28,13 +33,13 @@
 #define HCHUNK_DENSE 32        // FUTURE: make this an input parameter
 
 // returns Y of size m-by-n, or NULL on failure
-template <typename Entry> cholmod_dense *SuiteSparseQR_qmult
+template <typename Entry, typename Int> cholmod_dense *SuiteSparseQR_qmult
 (
     // inputs, not modified
     int method,             // 0,1,2,3
     cholmod_sparse *H,      // either m-by-nh or n-by-nh
     cholmod_dense *HTau,    // size 1-by-nh
-    Long *HPinv,            // size mh, identity permutation if NULL
+    Int *HPinv,            // size mh, identity permutation if NULL
     cholmod_dense *Xdense,  // size m-by-n with leading dimension ldx
 
     // workspace and parameters
@@ -43,8 +48,8 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_qmult
 {
     cholmod_dense *Ydense ;
     Entry *X, *Y, *X1, *Y1, *Z1, *Hx, *C, *V, *Z, *CV, *Tau ;
-    Long *Hp, *Hi, *Wi, *Wmap ;
-    Long i, k, zsize, nh, mh, vmax, hchunk, vsize, csize, cvsize, wisize, ldx,
+    Int *Hp, *Hi, *Wi, *Wmap ;
+    Int i, k, zsize, nh, mh, vmax, hchunk, vsize, csize, cvsize, wisize, ldx,
         m, n ;
     int ok = TRUE ;
 
@@ -56,14 +61,14 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_qmult
     RETURN_IF_NULL (H, NULL) ;
     RETURN_IF_NULL (HTau, NULL) ;
     RETURN_IF_NULL (Xdense, NULL) ;
-    Long xtype = spqr_type <Entry> ( ) ;
+    int xtype = spqr_type <Entry> ( ) ;
     RETURN_IF_XTYPE_INVALID (H, NULL) ;
     RETURN_IF_XTYPE_INVALID (HTau, NULL) ;
     RETURN_IF_XTYPE_INVALID (Xdense, NULL) ;
     cc->status = CHOLMOD_OK ;
 
-    Hp = (Long *) H->p ;
-    Hi = (Long *) H->i ;
+    Hp = (Int *) H->p ;
+    Hi = (Int *) H->i ;
     Hx = (Entry *) H->x ;
     nh = H->ncol ;
     mh = H->nrow ;
@@ -102,7 +107,7 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_qmult
     // allocate result Y
     // -------------------------------------------------------------------------
 
-    Ydense = cholmod_l_allocate_dense (m, n, m, xtype, cc) ;
+    Ydense = spqr_allocate_dense <Int> (m, n, m, xtype, cc) ;
     if (cc->status < CHOLMOD_OK)
     {
         // out of memory
@@ -125,7 +130,7 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_qmult
     if (method == SPQR_QX || method ==  SPQR_XQT)
     {
         // Z is needed only for methods SPQR_QX and SPQR_XQT
-        Z = (Entry *) cholmod_l_malloc (zsize, sizeof (Entry), cc) ;
+        Z = (Entry *) spqr_malloc <Int> (zsize, sizeof (Entry), cc) ;
     }
 
     hchunk = MIN (HCHUNK_DENSE, nh) ;
@@ -134,15 +139,15 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_qmult
     ASSERT (vmax <= mh) ;
 
     wisize = mh + vmax ;
-    Wi = (Long *) cholmod_l_malloc (wisize, sizeof (Long), cc) ;
+    Wi = (Int *) spqr_malloc <Int> (wisize, sizeof (Int), cc) ;
     Wmap = Wi + vmax ;              // Wmap is of size mh, Wi of size vmax
 
     if (cc->status < CHOLMOD_OK)
     {
         // out of memory; free workspace and result Y
-        cholmod_l_free_dense (&Ydense, cc) ;
-        cholmod_l_free (zsize,  sizeof (Entry), Z,  cc) ;
-        cholmod_l_free (wisize, sizeof (Long), Wi, cc) ;
+        spqr_free_dense <Int> (&Ydense, cc) ;
+        spqr_free <Int> (zsize,  sizeof (Entry), Z,  cc) ;
+        spqr_free <Int> (wisize, sizeof (Int), Wi, cc) ;
         return (NULL) ;
     }
 
@@ -177,7 +182,7 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_qmult
 
     if (ok)
     {
-        CV = (Entry *) cholmod_l_malloc (cvsize, sizeof (Entry), cc) ;
+        CV = (Entry *) spqr_malloc <Int> (cvsize, sizeof (Entry), cc) ;
     }
 
     // -------------------------------------------------------------------------
@@ -197,14 +202,14 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_qmult
         cvsize = spqr_add (csize, vsize, &ok) ;
         if (ok)
         {
-            CV = (Entry *) cholmod_l_malloc (cvsize, sizeof (Entry), cc) ;
+            CV = (Entry *) spqr_malloc <Int> (cvsize, sizeof (Entry), cc) ;
         }
         if (!ok || cc->status < CHOLMOD_OK)
         {
             // out of memory (or problem too large); free workspace and result Y
-            cholmod_l_free_dense (&Ydense, cc) ;
-            cholmod_l_free (zsize,  sizeof (Entry), Z,  cc) ;
-            cholmod_l_free (wisize, sizeof (Long), Wi, cc) ;
+            spqr_free_dense <Int> (&Ydense, cc) ;
+            spqr_free <Int> (zsize,  sizeof (Entry), Z,  cc) ;
+            spqr_free <Int> (wisize, sizeof (Int), Wi, cc) ;
             ERROR (CHOLMOD_OUT_OF_MEMORY, "out of memory") ;
             return (NULL) ;
         }
@@ -332,14 +337,14 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_qmult
     // free workspace and return Y
     // -------------------------------------------------------------------------
 
-    cholmod_l_free (cvsize, sizeof (Entry), CV, cc) ;
-    cholmod_l_free (zsize,  sizeof (Entry), Z,  cc) ;
-    cholmod_l_free (wisize, sizeof (Long), Wi, cc) ;
+    spqr_free <Int> (cvsize, sizeof (Entry), CV, cc) ;
+    spqr_free <Int> (zsize,  sizeof (Entry), Z,  cc) ;
+    spqr_free <Int> (wisize, sizeof (Int), Wi, cc) ;
 
-    if (CHECK_BLAS_INT && !cc->blas_ok)
+    if (sizeof (SUITESPARSE_BLAS_INT) < sizeof (Int) && !cc->blas_ok)
     {
         ERROR (CHOLMOD_INVALID, "problem too large for the BLAS") ;
-        cholmod_l_free_dense (&Ydense, cc) ;
+        spqr_free_dense <Int> (&Ydense, cc) ;
         return (NULL) ;
     }
 
@@ -349,13 +354,25 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_qmult
 
 // =============================================================================
 
-template cholmod_dense *SuiteSparseQR_qmult <double>
+template cholmod_dense *SuiteSparseQR_qmult <double, int64_t>
 (
     // inputs, not modified
     int method,             // 0,1,2,3
     cholmod_sparse *H,      // either m-by-nh or n-by-nh
     cholmod_dense *HTau,    // size 1-by-nh
-    Long *HPinv,            // size mh
+    int64_t *HPinv,            // size mh
+    cholmod_dense *Xdense,  // size m-by-n with leading dimension ldx
+
+    // workspace and parameters
+    cholmod_common *cc
+) ;
+template cholmod_dense *SuiteSparseQR_qmult <double, int32_t>
+(
+    // inputs, not modified
+    int method,             // 0,1,2,3
+    cholmod_sparse *H,      // either m-by-nh or n-by-nh
+    cholmod_dense *HTau,    // size 1-by-nh
+    int32_t *HPinv,            // size mh
     cholmod_dense *Xdense,  // size m-by-n with leading dimension ldx
 
     // workspace and parameters
@@ -364,19 +381,30 @@ template cholmod_dense *SuiteSparseQR_qmult <double>
 
 // =============================================================================
 
-template cholmod_dense *SuiteSparseQR_qmult <Complex>
+template cholmod_dense *SuiteSparseQR_qmult <Complex, int64_t>
 (
     // inputs, not modified
     int method,             // 0,1,2,3
     cholmod_sparse *H,      // either m-by-nh or n-by-nh
     cholmod_dense *HTau,    // size 1-by-nh
-    Long *HPinv,            // size mh
+    int64_t *HPinv,            // size mh
     cholmod_dense *Xdense,  // size m-by-n with leading dimension ldx
 
     // workspace and parameters
     cholmod_common *cc
 ) ;
+template cholmod_dense *SuiteSparseQR_qmult <Complex, int32_t>
+(
+    // inputs, not modified
+    int method,             // 0,1,2,3
+    cholmod_sparse *H,      // either m-by-nh or n-by-nh
+    cholmod_dense *HTau,    // size 1-by-nh
+    int32_t *HPinv,            // size mh
+    cholmod_dense *Xdense,  // size m-by-n with leading dimension ldx
 
+    // workspace and parameters
+    cholmod_common *cc
+) ;
 
 // =============================================================================
 // === SuiteSparseQR_qmult (sparse) ============================================
@@ -387,13 +415,13 @@ template cholmod_dense *SuiteSparseQR_qmult <Complex>
 #define XCHUNK 4            // FUTURE: make a parameter
 #define HCHUNK_SPARSE 4     // FUTURE: make a parameter
 
-template <typename Entry> cholmod_sparse *SuiteSparseQR_qmult
+template <typename Entry, typename Int> cholmod_sparse *SuiteSparseQR_qmult
 (
     // inputs, not modified
     int method,             // 0,1,2,3
     cholmod_sparse *H,      // size m-by-nh or n-by-nh
     cholmod_dense *HTau,    // size 1-by-nh
-    Long *HPinv,            // size mh, identity permutation if NULL
+    Int *HPinv,            // size mh, identity permutation if NULL
     cholmod_sparse *Xsparse,
 
     // workspace and parameters
@@ -402,8 +430,8 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_qmult
 {
     cholmod_sparse *Ysparse ;
     Entry *W, *W1, *Hx, *Xx, *C, *V, *CVW, *Tau ;
-    Long *Hp, *Hi, *Xp, *Xi, *Wi, *Wmap ;
-    Long i, k, ny, k1, xchunk, p, k2, m, n, nh, vmax, hchunk, vsize,
+    Int *Hp, *Hi, *Xp, *Xi, *Wi, *Wmap ;
+    Int i, k, ny, k1, xchunk, p, k2, m, n, nh, vmax, hchunk, vsize,
         csize, cvwsize, wsize, wisize ;
     int ok = TRUE ;
 
@@ -415,7 +443,7 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_qmult
     RETURN_IF_NULL (H, NULL) ;
     RETURN_IF_NULL (HTau, NULL) ;
     RETURN_IF_NULL (Xsparse, NULL) ;
-    Long xtype = spqr_type <Entry> ( ) ;
+    Int xtype = spqr_type <Entry> ( ) ;
     RETURN_IF_XTYPE_INVALID (H, NULL) ;
     RETURN_IF_XTYPE_INVALID (HTau, NULL) ;
     RETURN_IF_XTYPE_INVALID (Xsparse, NULL) ;
@@ -452,12 +480,12 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_qmult
     if (method == SPQR_XQT || method == SPQR_XQ)
     {
         cholmod_sparse *XT, *YT ;
-        XT = cholmod_l_transpose (Xsparse, 2, cc) ;
+        XT = spqr_transpose <Int> (Xsparse, 2, cc) ;
         YT = SuiteSparseQR_qmult <Entry>
             ((method == SPQR_XQT) ? SPQR_QX : SPQR_QTX, H, HTau, HPinv, XT, cc);
-        cholmod_l_free_sparse (&XT, cc) ;
-        Ysparse = cholmod_l_transpose (YT, 2, cc) ;
-        cholmod_l_free_sparse (&YT, cc) ;
+        spqr_free_sparse <Int> (&XT, cc) ;
+        Ysparse = spqr_transpose <Int> (YT, 2, cc) ;
+        spqr_free_sparse <Int> (&YT, cc) ;
         return (Ysparse) ;
     }
 
@@ -465,21 +493,21 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_qmult
     // get H and X
     // -------------------------------------------------------------------------
 
-    Hp = (Long *) H->p ;
-    Hi = (Long *) H->i ;
+    Hp = (Int *) H->p ;
+    Hi = (Int *) H->i ;
     Hx = (Entry *) H->x ;
     m = H->nrow ;
     nh = H->ncol ;
 
-    Xp = (Long *) Xsparse->p ;
-    Xi = (Long *) Xsparse->i ;
+    Xp = (Int *) Xsparse->p ;
+    Xi = (Int *) Xsparse->i ;
     Xx = (Entry *) Xsparse->x ;
     n = Xsparse->ncol ;
 
     Tau = (Entry *) HTau->x ;
 
     // -------------------------------------------------------------------------
-    // allocate Long workspace
+    // allocate Int workspace
     // -------------------------------------------------------------------------
 
     xchunk = MIN (XCHUNK, n) ;
@@ -489,7 +517,7 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_qmult
         &vmax, &vsize, &csize) ;
 
     wisize = m + vmax ;
-    Wi = (Long *) cholmod_l_malloc (wisize, sizeof (Long), cc) ;
+    Wi = (Int *) spqr_malloc <Int> (wisize, sizeof (Int), cc) ;
     Wmap = Wi + vmax ;              // Wmap is of size m, Wi is of size vmax
 
     if (cc->status < CHOLMOD_OK)
@@ -517,7 +545,7 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_qmult
 
     if (ok)
     {
-        CVW = (Entry *) cholmod_l_malloc (cvwsize, sizeof (Entry), cc) ;
+        CVW = (Entry *) spqr_malloc <Int> (cvwsize, sizeof (Entry), cc) ;
     }
 
     // -------------------------------------------------------------------------
@@ -539,13 +567,13 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_qmult
         cvwsize = spqr_add (cvwsize, vsize, &ok) ;
         if (ok)
         {
-            CVW = (Entry *) cholmod_l_malloc (cvwsize, sizeof (Entry), cc) ;
+            CVW = (Entry *) spqr_malloc <Int> (cvwsize, sizeof (Entry), cc) ;
         }
         if (!ok || cc->status < CHOLMOD_OK)
         {
             // still out of memory (or problem too large)
             ERROR (CHOLMOD_OUT_OF_MEMORY, "out of memory") ;
-            cholmod_l_free (wisize, sizeof (Long), Wi, cc) ;
+            spqr_free <Int> (wisize, sizeof (Int), Wi, cc) ;
             return (NULL) ;
         }
     }
@@ -563,12 +591,12 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_qmult
     // -------------------------------------------------------------------------
 
     // Y is a sparse matrix of size m-ny-n with space for m+1 entries
-    Ysparse = cholmod_l_allocate_sparse (m, n, m+1, TRUE, TRUE, 0, xtype, cc) ;
+    Ysparse = spqr_allocate_sparse <Int> (m, n, m+1, TRUE, TRUE, 0, xtype, cc) ;
     if (cc->status < CHOLMOD_OK)
     {
         // out of memory
-        cholmod_l_free (cvwsize, sizeof (Entry), CVW, cc) ;
-        cholmod_l_free (wisize,  sizeof (Long),  Wi,  cc) ;
+        spqr_free <Int> (cvwsize, sizeof (Entry), CVW, cc) ;
+        spqr_free <Int> (wisize,  sizeof (Int),  Wi,  cc) ;
         return (NULL) ;
     }
     ny = 0 ;
@@ -614,14 +642,14 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_qmult
             W1 = W ;
             for (k = k1 ; k < k2 ; k++)
             {
-                spqr_append (W1, NULL, Ysparse, &ny, cc) ;
+                spqr_append <Entry, Int> (W1, NULL, Ysparse, &ny, cc) ;
 
                 if (cc->status < CHOLMOD_OK)
                 {
                     // out of memory
-                    cholmod_l_free_sparse (&Ysparse, cc) ;
-                    cholmod_l_free (cvwsize, sizeof (Entry), CVW, cc) ;
-                    cholmod_l_free (wisize,  sizeof (Long),  Wi,  cc) ;
+                    spqr_free_sparse <Int> (&Ysparse, cc) ;
+                    spqr_free <Int> (cvwsize, sizeof (Entry), CVW, cc) ;
+                    spqr_free <Int> (wisize,  sizeof (Int),  Wi,  cc) ;
                     return (NULL) ;
                 }
 
@@ -670,9 +698,9 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_qmult
                 if (cc->status < CHOLMOD_OK)
                 {
                     // out of memory
-                    cholmod_l_free_sparse (&Ysparse, cc) ;
-                    cholmod_l_free (cvwsize, sizeof (Entry), CVW, cc) ;
-                    cholmod_l_free (wisize,  sizeof (Long),  Wi,  cc) ;
+                    spqr_free_sparse <Int> (&Ysparse, cc) ;
+                    spqr_free <Int> (cvwsize, sizeof (Entry), CVW, cc) ;
+                    spqr_free <Int> (wisize,  sizeof (Int),  Wi,  cc) ;
                     return (NULL) ;
                 }
                 W1 += m ;
@@ -684,14 +712,14 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_qmult
     // free workspace and reduce Y in size so that nnz (Y) == nzmax (Y)
     // -------------------------------------------------------------------------
 
-    cholmod_l_free (cvwsize, sizeof (Entry), CVW, cc) ;
-    cholmod_l_free (wisize,  sizeof (Long),  Wi,  cc) ;
-    cholmod_l_reallocate_sparse (cholmod_l_nnz (Ysparse,cc), Ysparse, cc) ;
+    spqr_free <Int> (cvwsize, sizeof (Entry), CVW, cc) ;
+    spqr_free <Int> (wisize,  sizeof (Int),  Wi,  cc) ;
+    spqr_reallocate_sparse <Int> (spqr_nnz <Int> (Ysparse,cc), Ysparse, cc) ;
 
-    if (CHECK_BLAS_INT && !cc->blas_ok)
+    if (sizeof (SUITESPARSE_BLAS_INT) < sizeof (Int) && !cc->blas_ok)
     {
         ERROR (CHOLMOD_INVALID, "problem too large for the BLAS") ;
-        cholmod_l_free_sparse (&Ysparse, cc) ;
+        spqr_free_sparse <Int> (&Ysparse, cc) ;
         return (NULL) ;
     }
 
@@ -701,13 +729,25 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_qmult
 
 // =============================================================================
 
-template cholmod_sparse *SuiteSparseQR_qmult <double>
+template cholmod_sparse *SuiteSparseQR_qmult <double, int32_t>
 (
     // inputs, not modified
     int method,                 // 0,1,2,3
     cholmod_sparse *H,          // size m-by-nh or n-by-nh
     cholmod_dense *HTau,        // size 1-by-nh
-    Long *HPinv,                // size mh
+    int32_t *HPinv,                // size mh
+    cholmod_sparse *Xsparse,
+
+    // workspace and parameters
+    cholmod_common *cc
+) ;
+template cholmod_sparse *SuiteSparseQR_qmult <double, int64_t>
+(
+    // inputs, not modified
+    int method,                 // 0,1,2,3
+    cholmod_sparse *H,          // size m-by-nh or n-by-nh
+    cholmod_dense *HTau,        // size 1-by-nh
+    int64_t *HPinv,                // size mh
     cholmod_sparse *Xsparse,
 
     // workspace and parameters
@@ -716,13 +756,25 @@ template cholmod_sparse *SuiteSparseQR_qmult <double>
 
 // =============================================================================
 
-template cholmod_sparse *SuiteSparseQR_qmult <Complex>
+template cholmod_sparse *SuiteSparseQR_qmult <Complex, int32_t>
 (
     // inputs, not modified
     int method,                 // 0,1,2,3
     cholmod_sparse *H,          // size m-by-nh or n-by-nh
     cholmod_dense *HTau,        // size 1-by-nh
-    Long *HPinv,                // size mh
+    int32_t *HPinv,                // size mh
+    cholmod_sparse *Xsparse,
+
+    // workspace and parameters
+    cholmod_common *cc
+) ;
+template cholmod_sparse *SuiteSparseQR_qmult <Complex, int64_t>
+(
+    // inputs, not modified
+    int method,                 // 0,1,2,3
+    cholmod_sparse *H,          // size m-by-nh or n-by-nh
+    cholmod_dense *HTau,        // size 1-by-nh
+    int64_t *HPinv,                // size mh
     cholmod_sparse *Xsparse,
 
     // workspace and parameters
