@@ -9,16 +9,16 @@
 
 #include "spqr.hpp"
 
-int64_t spqr_fcsize    // returns # of entries in C of current front F
+template <typename Int> Int spqr_fcsize    // returns # of entries in C of current front F
 (
     // input, not modified
-    int64_t m,                 // # of rows in F
-    int64_t n,                 // # of columns in F
-    int64_t npiv,              // number of pivotal columns in F
-    int64_t rank               // the C block starts at F (rank,npiv)
+    Int m,                 // # of rows in F
+    Int n,                 // # of columns in F
+    Int npiv,              // number of pivotal columns in F
+    Int rank               // the C block starts at F (rank,npiv)
 )
 {
-    int64_t cm, cn, csize ;
+    Int cm, cn, csize ;
     ASSERT (m >= 0 && n >= 0 && npiv >= 0 && npiv <= n) ;
     ASSERT (rank >= 0 && rank <= MIN (m,npiv)) ;
     cn = n - npiv ;                         // number of columns of C
@@ -28,3 +28,20 @@ int64_t spqr_fcsize    // returns # of entries in C of current front F
     csize = (cm * (cm+1)) / 2 + cm * (cn - cm) ;
     return (csize) ;                        // return # of entries in C
 }
+
+template int32_t spqr_fcsize <int32_t>    // returns # of entries in C of current front F
+(
+    // input, not modified
+    int32_t m,                 // # of rows in F
+    int32_t n,                 // # of columns in F
+    int32_t npiv,              // number of pivotal columns in F
+    int32_t rank               // the C block starts at F (rank,npiv)
+) ;
+template int64_t spqr_fcsize <int64_t>    // returns # of entries in C of current front F
+(
+    // input, not modified
+    int64_t m,                 // # of rows in F
+    int64_t n,                 // # of columns in F
+    int64_t npiv,              // number of pivotal columns in F
+    int64_t rank               // the C block starts at F (rank,npiv)
+) ;
